"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getScripts = void 0;

var _path = require("path");

const loadPkgModule = (pkgDir, path) => {
  try {
    return require((0, _path.join)(pkgDir, path));
  } catch (err) {
    if (err.code !== 'MODULE_NOT_FOUND') {
      throw err;
    }
  }

  return {};
};

const getPkgScripts = pkgDir => loadPkgModule(pkgDir, 'package.json').scripts || {};

const getScriptsModuleScripts = pkgDir => loadPkgModule(pkgDir, 'scripts');

const listScriptFiles = (pkgDir, fs) => {
  try {
    return fs.readdirSync((0, _path.join)(pkgDir, 'scripts'));
  } catch (_unused) {
    // we ignore if there is no scripts dir containing modules
    return [];
  }
};

const getScriptsDirScripts = (pkgDir, fs) => {
  const scripts = {};

  for (const fileName of listScriptFiles(pkgDir, fs)) {
    const name = (0, _path.basename)(fileName, '.js');

    if ((0, _path.extname)(fileName) === '.js' && name !== 'index') {
      // TODO: make @babel/register optional
      scripts[name] = `node -r @babel/register ./scripts/${fileName}`;
    }
  }

  return scripts;
};

const getScripts = (pkgDir, fs) => ({ ...getPkgScripts(pkgDir),
  ...getScriptsModuleScripts(pkgDir),
  ...getScriptsDirScripts(pkgDir, fs)
});

exports.getScripts = getScripts;